<?php
require_once 'PhpMyAdmin/MoTranslator/autoload.php';
require_once 'PhpMyAdmin/ShapeFile/autoload.php';
require_once 'PhpMyAdmin/SqlParser/autoload.php';
require_once 'Symfony/Component/ExpressionLanguage/autoload.php';
require_once 'Symfony/Component/DependencyInjection/autoload.php';
require_once 'Symfony/Component/Config/autoload.php';
require_once 'Symfony/Component/Yaml/autoload.php';
require_once 'phpseclib/autoload.php';
require_once 'Twig/autoload.php';
require_once 'PhpMyAdmin/Twig/Extensions/autoload.php';
require_once 'Williamdes/MariaDBMySQLKBS/autoload.php';
require_once 'ReCaptcha/autoload.php';
@include_once 'tcpdf/tcpdf.php';

// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___ $classes[$cn];
        }
    },
    true,
    false
);
// @codeCoverageIgnoreEnd
